@@ -6,13 +6,18 @@ CREATED_DATE_FORMAT = '%b %d, %Y %I:%M%p'
 
 
 class Clock:
-    def __init__(self,  cron: str = '* * * * *', timezone_utc_minus: int = 0, timer_duration_list_max: int = 10):
-        self.cron = Cron(cron)
+    def __init__(
+            self,
+            cron: str = '* * * * *',
+            utc_offset: int = 0,
+            timer_duration_list_max: int = 10
+    ):
+        self.cron = Cron(value=cron, utc_offset=utc_offset)
 
-        self.timezone_utc_minus = timezone_utc_minus
+        self.utc_offset = utc_offset
 
         self.created_utc = datetime.utcnow()
-        self.created_tz = datetime.utcnow() - timedelta(hours=timezone_utc_minus)
+        self.created_tz = datetime.utcnow() + timedelta(hours=utc_offset)
 
         self.timer_duration_list_max = timer_duration_list_max
         self.timer_duration_list = []
@@ -25,6 +30,7 @@ class Clock:
     def as_dict(self):
         return {
             'created': self.created_tz_verbose,
+            'now': self.now_tz_verbose,
             'next_run_datetime': self.next_run_datetime_verbose,
             'timer_last_duration': f'{self.timer_last_duration:.2f}',
             'timer_average_duration': f'{self.timer_average_duration:.2f}',
@@ -47,6 +53,10 @@ class Clock:
     def created_tz_verbose(self):
         return self.created_tz.strftime(CREATED_DATE_FORMAT)
 
+    @property
+    def now_tz_verbose(self):
+        return (datetime.utcnow() + timedelta(hours=self.utc_offset)).strftime(CREATED_DATE_FORMAT)
+
     def is_past_next_run_datetime(self):
         if self.cron.is_past_next_datetime():
             return True
