@@ -1,7 +1,11 @@
 function Container() {
     return {
         data: {
-            "groups": []
+            "groups": [],
+        },
+
+        job_details: {
+
         },
 
         get_json_data(json_data) {
@@ -18,18 +22,32 @@ function Container() {
                 }
             }
 
-            xmlHttp.open("GET", 'api/');
+            xmlHttp.open("GET", 'worker_api/');
             xmlHttp.send();
         },
 
         start() {
             this.ajax_json_request()
             setInterval(this.ajax_json_request, 2000)
-            setTimeout(function() {
+            setTimeout(function () {
                 document.getElementById("loading").classList.add("d-none");
                 document.getElementById("loading").classList.remove("d-block");
                 document.getElementById("container").classList.remove("d-none");
             }, 500)
+        },
+
+        async get_job_details(id) {
+            let response = await fetch("job_api/" + id);
+            let job = document.getElementById("job-" + id)
+            if (job.style.display === 'block') {
+                job.style.display = 'none'
+            } else {
+                job.style.display = 'block'
+            }
+            let responseText = await response.text();
+            let json_data = JSON.parse(responseText)
+            this.job_details[json_data.job_detail.id] = json_data.job_detail
+            // console.log(JSON.stringify(this.job_details))
         }
 
     }
