@@ -11,26 +11,43 @@ from robit.worker.web_server import WorkerWebServer
 
 
 class Worker:
-    def __init__(self, name: str, web_server: bool = True, web_server_port: int = 8000, key: str = None, monitor_address: str = None, monitor_key: str = None):
+    def __init__(
+            self,
+            name: str,
+            web_server: bool = True,
+            web_server_address: str = '127.0.0.1',
+            web_server_port: int = 8000,
+            key: str = None,
+            monitor_address: str = None,
+            monitor_port: int = 8200,
+            monitor_key: str = None,
+            utc_offset: int = 0
+    ):
         self.id = Id()
         self.name = Name(name)
-        self.clock = Clock()
+        self.clock = Clock(utc_offset=utc_offset)
         self.health = Health()
         self.status = Status()
 
         if web_server:
-            self.web_server = WorkerWebServer(port=web_server_port, key=key)
+            self.web_server = WorkerWebServer(
+                address=web_server_address,
+                port=web_server_port,
+                key=key,
+                html_replace_dict={'||title||': self.name.__str__()}
+            )
         else:
             self.web_server = None
 
         self.monitor_address = monitor_address
+        self.monitor_port = monitor_port
         self.monitor_key = monitor_key
 
         self.group_dict = dict()
 
     def add_job(self, name, method, group='Default', **kwargs):
         if group not in self.group_dict:
-            self.group_dict[group] = Group(name=group)
+            self.group_dict[group] = Group(name=group, utc_offset=self.clock.utc_offset)
 
         self.group_dict[group].add_job(name, method, **kwargs)
 
@@ -41,7 +58,8 @@ class Worker:
             'groups': self.calculate_groups_to_list(),
             'health': self.health.__str__(),
             'status': self.status.__str__(),
-            'created': self.clock.created_tz_verbose
+            'clock': self.clock.as_dict(),
+            'job_details': self.job_detail_dict()
         }
 
     def as_dict_to_monitor(self):
@@ -49,7 +67,7 @@ class Worker:
             'id': self.id.__str__(),
             'name': self.name.__str__(),
             'health': self.health.__str__(),
-            'created': self.clock.created_tz_verbose
+            'clock': self.clock.as_dict(),
         }
 
     def calculate_groups_to_list(self):
@@ -62,6 +80,14 @@ class Worker:
 
         return group_list
 
+    def job_detail_dict(self):
+        job_detail_dict = dict()
+
+        for group in self.group_dict.values():
+            job_detail_dict = {**job_detail_dict, **group.job_list_as_dict_full()}
+
+        return job_detail_dict
+
     def restart(self):
         pass
 
